feat(1.103): update to 1.103 (#2447)

This commit is contained in:
Baptiste Augrain
2025-08-09 01:10:08 +02:00
committed by GitHub
parent c6eec8f00d
commit 57832e4688
17 changed files with 254 additions and 170 deletions

View File

@@ -2,5 +2,5 @@
set -ex
export ELECTRON_VERSION="35.4.0"
export ELECTRON_VERSION="37.2.5"
export VSCODE_ELECTRON_TAG="v${ELECTRON_VERSION}"

View File

@@ -1,9 +1,11 @@
139fa3fda65865ee141b0f411945eff7b26c4bb35a2647e55d38aeedcc08e129 *chromedriver-v35.4.0-linux-loong64.zip
319dab705a38634e6b0c4090eaf17d171e493432cebdb96d0c6956f2dad4feba *electron-v35.4.0-linux-loong64-debug.zip
7cc0f0feeb987d22096a9d6c17b5ef35705b948d0814127eb666d3aefa989e79 *electron-v35.4.0-linux-loong64-symbols.zip
37d95342b35c20e36f85ef3cccf8d714e83ca8fd58f8413b0b6b46b251a0f47d *electron-v35.4.0-linux-loong64.zip
617060c7b79d3a311c750fb8795ef12679b3e522d70d29edd11f3f367ae2659c *hunspell-dictionaries.zip
be95f332f4d4760fde24ef88fb70dab1ef4bb059dfd0d740eaa8cbe10f6f6fbb *libcxx-headers.zip
0a0c40917b61afa3da0e1661dd78dad54c4ad1c0fc7d8c923a453d969638dd8b *libcxx-objects-v35.4.0-linux-loong64.zip
b3fdfe044f22c60de5589eb57be9d6d0fdbf30439ff2b67541318356dc331faa *libcxxabi-headers.zip
84dc28d1402a347db08a834228a27626bff8b853c21146141863ce8202a56e72 *mksnapshot-v35.4.0-linux-loong64.zip
0bc435a6989f120b1f748cd2f8d3fa7ed731c54a0ad797271e479539dca5c4fe *chromedriver-v37.2.5-linux-loong64.zip
6a355cac6c8b02deb413d024ff3224f03717cc0790e3f5a872891ecf79ade20e *electron-v37.2.5-linux-loong64-debug.zip
c091db1993b2bda5426a678c428c5ffc71af9228abc4891a493a1d318e250b0a *electron-v37.2.5-linux-loong64-symbols.zip
d3f615c3ec265a2adbc0ed9088a65e96aa90b392ecd1ea17e8e4dc82728f4a5d *electron-v37.2.5-linux-loong64.zip
17e05db81f5b0cff1327ac153bd20838b3332b78de1b2ffa235e27a30a15024d *ffmpeg-v37.2.5-linux-loong64.zip
eaf1efb230cd9bfee7acd8b553c602ff396c2f667837e968b4c1d5542448b0b3 *hunspell-dictionaries.zip
3eb8b3199f764c63f82960cb1e1945f70af348873133bf9fd70daeefa3ca1bfb *libcxx-headers.zip
2a5ad06e845d59d89b74a97cd2befcfad02f951f8083f02645a9edbb4e7fdcb7 *libcxx-objects-v37.2.5-linux-loong64.zip
24eec3c74d5a05eba53524866a009e257e52e65257caa8e6fda07b82321885eb *libcxxabi-headers.zip
a4015814d6651cf5511b04307aeef51b739d05eed7ff8ab819739dabd0047309 *mksnapshot-v37.2.5-linux-loong64.zip
d1ed2413e007d7adbcd7291158647cfd4908739b034d021c123ca3d11513c31a *node-v37.2.5-headers.tar.gz

View File

@@ -2,5 +2,5 @@
set -ex
export ELECTRON_VERSION="35.4.0"
export ELECTRON_VERSION="37.2.3"
export VSCODE_ELECTRON_TAG="v${ELECTRON_VERSION}"

View File

@@ -1,11 +1,10 @@
c010d5d6e71b5e264fbf9c489793255a7f8eeaf052ee397f422beee69dc14142 *chromedriver-v35.4.0-linux-ppc64le.zip
a34c7355c47a401c32c0d4dfc2ed563ff34e7d3a21d81711742ede3e997c1120 *electron-v35.4.0-linux-ppc64le-debug.zip
41d6dce1d6f9708bb2e7ba8abb2c9634a1617f4efd499d184b31db4e2487b9c4 *electron-v35.4.0-linux-ppc64le-symbols.zip
9d2e29007fc1126ffca8c340531f3d8df7403fb0cfbe6301522dc3ee9d8ed8df *electron-v35.4.0-linux-ppc64le.zip
22c1723e008a8f2db879588d705ba528894c5d56053539f29de54de30cbe36a3 *electron.d.ts
29ffe919d9d7e6c4253f75bccfc8a56cb524dc4525a05b11f1b5d7a28b83fc77 *ffmpeg-v35.4.0-linux-ppc64le.zip
e14732b467e29f89231fe938a976e101ce9895e40eb3a837200f8f6e129b638b *hunspell_dictionaries.zip
dba6e62837a78f87bdc0c4acbbde2cdb88639d7ec5685e666a7b101e15d68d0c *libcxx-objects-v35.4.0-linux-ppc64le.zip
14916583d55720189f6afc9d55bb5e2ad81ab30fea8a1790026e64575c0b8dc4 *libcxx_headers.zip
0ce292706006d9e17c590f2704d844e2b837c37da28ff9baab36d7497c4917a0 *libcxxabi_headers.zip
962262bc16dc1d452f67656b897899c471b11d6e6e37bccd536bc0cb0b36ef47 *mksnapshot-v35.4.0-linux-ppc64le.zip
877785ae2383a8a222fa37bda98c148b145931ff8714614aaf330d15d6f92710 *chromedriver-v37.2.3-linux-ppc64le.zip
5ce746efac98a0d83699ef0e03497867ed34d936a268551f26eb2e2972c4d5f5 *electron-v37.2.3-linux-ppc64le-debug.zip
f0ac8a9a9b6c1e330edd53fedaee29699c540691993ace4bb938cdd369895b89 *electron-v37.2.3-linux-ppc64le-symbols.zip
6dc2ac4a8fd4565948ac330be371436d2534aaea633d17ac7743fce8aac42ef0 *electron-v37.2.3-linux-ppc64le.zip
6358a83a03a801d6a85559179e4f12307dee693043ffb26fd40585f369f7db76 *electron.d.ts
25a5ec559f683df305faa9eb082514a9e6dff9f983b7724ddbd82a34bef4890b *hunspell_dictionaries.zip
9da591f8eabbdeba1a51f1b2ec7f2627eaa07d77d0263b6b16abc87a00e2f287 *libcxx-objects-v37.2.3-linux-ppc64le.zip
519a41987f56c133b91affbb13f8fa5331eda9da8750325fae84444532177e02 *libcxx_headers.zip
8607d01b3c828602b3f359458587d5ffa883695756edebf4547aadb0847fdaa9 *libcxxabi_headers.zip
1d40ebef530616b35031333e569247dd265704b496f35ec256220ae081c340c1 *mksnapshot-v37.2.3-linux-ppc64le.zip

View File

@@ -2,5 +2,5 @@
set -ex
export ELECTRON_VERSION="35.4.0"
export ELECTRON_VERSION="37.2.3"
export VSCODE_ELECTRON_TAG="v${ELECTRON_VERSION}.riscv1"

View File

@@ -1,11 +1,11 @@
62a100f36cb8898ca4df50b6160c5fc72618f4447486a154b3521e2d5ca58a2a *chromedriver-v35.4.0-linux-riscv64.zip
92408a3b8a0fdb1be0cdf9473b97a4bb5a0ec3351d3519f5a15831b071eaad27 *electron-v35.4.0-linux-riscv64-debug.tar.zst
7a7fc08874d7dd9f24a27e06ce4f10223d0b81860408a5a6e67441ca7a7a0df9 *electron-v35.4.0-linux-riscv64-symbols.tar.zst
b61f163296cc498e459a71839d68f7f1e2d9a5e2cb0ac9e85b1e360f437f4ecc *electron-v35.4.0-linux-riscv64.zip
41cd1f566a422a59370fc8928a73a4255336f7d870f3eeeabed99b56eb482c6d *ffmpeg-v35.4.0-linux-riscv64.zip
53b80b77c753d06a01349f7cb1c4eec7d4565366a67fd94abb5748f3204b1bd4 *hunspell-dictionaries.zip
252d1279aeafe27e1e54f10fbf9cf07ef0ae49d5b1ff8c7c9876ebba616a878b *libcxx-headers.zip
522a5719369b66749cd966963a94db1c5837d5bc4aecf77caf32f99a8978bfaa *libcxx-objects-v35.4.0-linux-riscv64.zip
48fb04fb8616d48b9a7125e5b6a038b29b5858f170ae65c4e09b576b7931f7ae *libcxxabi-headers.zip
f2ab79663741550142623e7af5aa0fc62eff200c43a8c42d5476e06ff70858ca *mksnapshot-v35.4.0-linux-riscv64.zip
2f4c2d4212fd83f284fef12e1feae01d79bbbd1a68ee05128f1717e0ecfb2b17 *node-v35.4.0-headers.tar.gz
bec3076d684af4ab7700f13861c3257dc17198970eb498ff2e388db71f61898e *chromedriver-v37.2.3-linux-riscv64.zip
c670aba1b907ef9cbcdb2dccd742604f897eef4719f7ad46f34925197f7ae208 *electron-v37.2.3-linux-riscv64-debug.tar.zst
3ee5a9d29c611a6c685caa291698c3b5f1041bd11b3726137d41931457d6a113 *electron-v37.2.3-linux-riscv64-symbols.tar.zst
33f16380975b2087308f096e4329639f839c58aa1b9cccbee0a915bf3ed7b976 *electron-v37.2.3-linux-riscv64.zip
0ef484d10dd15bb4b44e5862ff8070ec09d94ca0b7c6b062e88c64fa343e2408 *ffmpeg-v37.2.3-linux-riscv64.zip
218a633300feb50ed57ab751374bac8693615ff192c2437067a4bceef84c9cf8 *hunspell-dictionaries.zip
abe24654e394d057dc2bdea9533fcd1790becb822b53d543165c74470694e818 *libcxx-headers.zip
1e6972b9125d1864f32d0f5d1084cf4ea56f7dd2227505271dde15439942c0e4 *libcxx-objects-v37.2.3-linux-riscv64.zip
55fdbc0fc65e176e50c3492dd50a18c9d23e2bd0e45a00a34118d46ed583a8d0 *libcxxabi-headers.zip
b017a16c8f0d8c8076ec71fba5a043951dd88e4fc7d8e8720906a0b9b4a141aa *mksnapshot-v37.2.3-linux-riscv64.zip
0259b1abf0bc8aedb114bac75aadcbb1860fd13ae32a876702ca8e722581f8b2 *node-v37.2.3-headers.tar.gz

14
build/windows/appx/build.sh Executable file
View File

@@ -0,0 +1,14 @@
#!/usr/bin/env bash
set -ex
# Add Windows SDK to path
SDK='/C/Program Files (x86)/Windows Kits/10/bin/10.0.26100.0/x64'
export PATH="${SDK}:${PATH}"
APPX_NAME="${BINARY_NAME//-/_}"
makeappx pack /d "../../../VSCode-win32-${VSCODE_ARCH}/appx/manifest" /p "../../../VSCode-win32-${VSCODE_ARCH}/appx/${APPX_NAME}_${VSCODE_ARCH}.appx" /nv
# Remove the raw manifest folder
rm -rf "../../../VSCode-win32-${VSCODE_ARCH}/appx/manifest"

View File

@@ -73,37 +73,37 @@ index be7eea1..0737bab 100644
+const bumpEngineForImplicitActivationEvents = l10n.t("This activation event can be removed for extensions targeting engine version ^1.75 as !!APP_NAME!! will generate these automatically from your package.json contribution declarations.");
const starActivation = l10n.t("Using '*' activation is usually a bad idea as it impacts performance.");
diff --git a/extensions/git/package.nls.json b/extensions/git/package.nls.json
index 403f704..2f838cd 100644
index 07204a1..1b2a36d 100644
--- a/extensions/git/package.nls.json
+++ b/extensions/git/package.nls.json
@@ -228,3 +228,3 @@
@@ -235,3 +235,3 @@
"{Locked='](command:git.showOutput'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -256,4 +256,4 @@
@@ -263,4 +263,4 @@
"config.showCommitInput": "Controls whether to show the commit input in the Git source control panel.",
- "config.terminalAuthentication": "Controls whether to enable VS Code to be the authentication handler for Git processes spawned in the Integrated Terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
- "config.terminalGitEditor": "Controls whether to enable VS Code to be the Git editor for Git processes spawned in the integrated terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
+ "config.terminalAuthentication": "Controls whether to enable !!APP_NAME!! to be the authentication handler for Git processes spawned in the Integrated Terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
+ "config.terminalGitEditor": "Controls whether to enable !!APP_NAME!! to be the Git editor for Git processes spawned in the integrated terminal. Note: Terminals need to be restarted to pick up a change in this setting.",
"config.timeline.showAuthor": "Controls whether to show the commit author in the Timeline view.",
@@ -324,3 +324,3 @@
@@ -332,3 +332,3 @@
"{Locked='](command:workbench.extensions.search?%22%40category%3A%5C%22scm%20providers%5C%22%22'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -334,3 +334,3 @@
@@ -342,3 +342,3 @@
"{Locked='](command:workbench.extensions.search?%22%40category%3A%5C%22scm%20providers%5C%22%22'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -344,3 +344,3 @@
@@ -352,3 +352,3 @@
"{Locked='](command:workbench.extensions.search?%22%40category%3A%5C%22scm%20providers%5C%22%22'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -356,6 +356,6 @@
@@ -364,6 +364,6 @@
"view.workbench.scm.disabled": {
- "message": "If you would like to use Git features, please enable Git in your [settings](command:workbench.action.openSettings?%5B%22git.enabled%22%5D).\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "If you would like to use Git features, please enable Git in your [settings](command:workbench.action.openSettings?%5B%22git.enabled%22%5D).\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -112,7 +112,7 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -364,6 +364,6 @@
@@ -372,6 +372,6 @@
"view.workbench.scm.empty": {
- "message": "In order to use Git features, you can open a folder containing a Git repository or clone from a URL.\n[Open Folder](command:vscode.openFolder)\n[Clone Repository](command:git.cloneRecursive)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "In order to use Git features, you can open a folder containing a Git repository or clone from a URL.\n[Open Folder](command:vscode.openFolder)\n[Clone Repository](command:git.cloneRecursive)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -121,7 +121,7 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -372,6 +372,6 @@
@@ -380,6 +380,6 @@
"view.workbench.scm.folder": {
- "message": "The folder currently open doesn't have a Git repository. You can initialize a repository which will enable source control features powered by Git.\n[Initialize Repository](command:git.init?%5Btrue%5D)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The folder currently open doesn't have a Git repository. You can initialize a repository which will enable source control features powered by Git.\n[Initialize Repository](command:git.init?%5Btrue%5D)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -130,7 +130,7 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -380,6 +380,6 @@
@@ -388,6 +388,6 @@
"view.workbench.scm.workspace": {
- "message": "The workspace currently open doesn't have any folders containing Git repositories. You can initialize a repository on a folder which will enable source control features powered by Git.\n[Initialize Repository](command:git.init)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The workspace currently open doesn't have any folders containing Git repositories. You can initialize a repository on a folder which will enable source control features powered by Git.\n[Initialize Repository](command:git.init)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -139,7 +139,7 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -388,6 +388,6 @@
@@ -396,6 +396,6 @@
"view.workbench.scm.emptyWorkspace": {
- "message": "The workspace currently open doesn't have any folders containing Git repositories.\n[Add Folder to Workspace](command:workbench.action.addRootFolder)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "The workspace currently open doesn't have any folders containing Git repositories.\n[Add Folder to Workspace](command:workbench.action.addRootFolder)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -148,18 +148,13 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -406,3 +406,3 @@
"{Locked='](command:workbench.action.openSettings?%5B%22git.openRepositoryInParentFolders%22%5D'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -415,3 +415,3 @@
@@ -414,3 +414,3 @@
"{Locked='](command:workbench.action.openSettings?%5B%22git.openRepositoryInParentFolders%22%5D'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -423,3 +423,3 @@
"{Locked='](command:git.manageUnsafeRepositories'}",
"{Locked='](command:workbench.action.openSettings?%5B%22git.openRepositoryInParentFolders%22%5D'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -168,7 +163,12 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -436,6 +436,6 @@
@@ -439,3 +439,3 @@
"{Locked='](command:git.manageUnsafeRepositories'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -444,6 +444,6 @@
"view.workbench.scm.closedRepository": {
- "message": "A Git repository was found that was previously closed.\n[Reopen Closed Repository](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "A Git repository was found that was previously closed.\n[Reopen Closed Repository](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -177,7 +177,7 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -444,6 +444,6 @@
@@ -452,6 +452,6 @@
"view.workbench.scm.closedRepositories": {
- "message": "Git repositories were found that were previously closed.\n[Reopen Closed Repositories](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm).",
+ "message": "Git repositories were found that were previously closed.\n[Reopen Closed Repositories](command:git.reopenClosedRepositories)\nTo learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm).",
@@ -186,12 +186,12 @@ index 403f704..2f838cd 100644
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -455,3 +455,3 @@
@@ -463,3 +463,3 @@
"{Locked='](command:git.clone'}",
- "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for VS Code",
+ "Do not translate the 'command:*' part inside of the '(..)'. It is an internal command syntax for !!APP_NAME!!",
"Please make sure there is no space between the right bracket and left parenthesis: ]( this is an internal syntax for links"
@@ -459,3 +459,3 @@
@@ -467,3 +467,3 @@
},
- "view.workbench.learnMore": "To learn more about how to use Git and source control in VS Code [read our docs](https://aka.ms/vscode-scm)."
+ "view.workbench.learnMore": "To learn more about how to use Git and source control in !!APP_NAME!! [read our docs](https://aka.ms/vscode-scm)."
@@ -361,7 +361,7 @@ index 7d6694c..83b2599 100644
+ "comment": "The simpler (?<=\\bProcess\\.|\\bCommandLine\\.) breaks !!APP_NAME!! / Atom, see https://github.com/textmate/swift.tmbundle/issues/29",
"name": "support.variable.swift",
diff --git a/extensions/typescript-language-features/package.nls.json b/extensions/typescript-language-features/package.nls.json
index 5de96a8..563d7eb 100644
index e59234f..9c26f4d 100644
--- a/extensions/typescript-language-features/package.nls.json
+++ b/extensions/typescript-language-features/package.nls.json
@@ -80,4 +80,4 @@
@@ -393,7 +393,7 @@ index 5de96a8..563d7eb 100644
- "configuration.tsserver.nodePath": "Run TS Server on a custom Node installation. This can be a path to a Node executable, or 'node' if you want VS Code to detect a Node installation.",
+ "configuration.tsserver.nodePath": "Run TS Server on a custom Node installation. This can be a path to a Node executable, or 'node' if you want !!APP_NAME!! to detect a Node installation.",
"configuration.updateImportsOnPaste": "Automatically update imports when pasting code. Requires TypeScript 5.6+.",
@@ -238,7 +238,7 @@
@@ -237,7 +237,7 @@
"walkthroughs.nodejsWelcome.debugJsFile.title": "Run and Debug your JavaScript",
- "walkthroughs.nodejsWelcome.debugJsFile.description": "Once you've installed Node.js, you can run JavaScript programs at a terminal by entering ``node your-file-name.js``\nAnother easy way to run Node.js programs is by using VS Code's debugger which lets you run your code, pause at different points, and help you understand what's going on step-by-step.\n[Start Debugging](command:javascript-walkthrough.commands.debugJsFile)",
- "walkthroughs.nodejsWelcome.debugJsFile.altText": "Debug and run your JavaScript code in Node.js with Visual Studio Code.",
@@ -452,7 +452,7 @@ index 4201d6d..ded6803 100644
+ vscode.l10n.t("The JS/TS language service crashed.\nThis may be caused by a plugin contributed by one of these extensions: {0}.\nPlease try disabling these extensions before filing an issue against !!APP_NAME!!.", pluginExtensionList));
} else {
diff --git a/extensions/vscode-api-tests/package.json b/extensions/vscode-api-tests/package.json
index 440d495..41b94c3 100644
index 6f4ef62..abc1588 100644
--- a/extensions/vscode-api-tests/package.json
+++ b/extensions/vscode-api-tests/package.json
@@ -2,3 +2,3 @@
@@ -530,7 +530,7 @@ index a351aa7..c32e3ef 100644
+ throw Error(`Failed to download and unzip !!APP_NAME!! ${quality} - ${commit}`);
}
diff --git a/extensions/vscode-test-resolver/src/extension.ts b/extensions/vscode-test-resolver/src/extension.ts
index 2fab3ec..1195e3d 100644
index 74d25c6..878e228 100644
--- a/extensions/vscode-test-resolver/src/extension.ts
+++ b/extensions/vscode-test-resolver/src/extension.ts
@@ -178,3 +178,3 @@ export function activate(context: vscode.ExtensionContext) {
@@ -557,7 +557,7 @@ index fc3b6ad..0675813 100644
+ ' // This can help in cases where you see rendering issues in !!APP_NAME!!.',
' // "disable-hardware-acceleration": true',
diff --git a/src/vs/code/electron-main/app.ts b/src/vs/code/electron-main/app.ts
index 49ae28f..e8b81fb 100644
index 3f772f5..8e0a96e 100644
--- a/src/vs/code/electron-main/app.ts
+++ b/src/vs/code/electron-main/app.ts
@@ -526,3 +526,3 @@ export class CodeApplication extends Disposable {
@@ -671,10 +671,10 @@ index 0535ddd..2478997 100644
+ console.error('Unable to connect to !!APP_NAME!! server: ' + message);
console.error(err);
diff --git a/src/vs/workbench/api/browser/mainThreadAuthentication.ts b/src/vs/workbench/api/browser/mainThreadAuthentication.ts
index 1d3463e..fa6ac0c 100644
index 4dfd750..fcb5846 100644
--- a/src/vs/workbench/api/browser/mainThreadAuthentication.ts
+++ b/src/vs/workbench/api/browser/mainThreadAuthentication.ts
@@ -454,3 +454,3 @@ export class MainThreadAuthentication extends Disposable implements MainThreadAu
@@ -462,3 +462,3 @@ export class MainThreadAuthentication extends Disposable implements MainThreadAu
owner: 'TylerLeonhardt';
- comment: 'Used to see which extensions are using the VSCode client id override';
+ comment: 'Used to see which extensions are using the !!APP_NAME!! client id override';
@@ -689,10 +689,10 @@ index fdf354d..b196297 100644
+ description: localize({ key: 'vscode.extension.contributes.views.containers.id', comment: ['Contribution refers to those that an extension contributes to !!APP_NAME!! through an extension/contribution point. '] }, "Unique id used to identify the container in which views can be contributed using 'views' contribution point"),
type: 'string',
diff --git a/src/vs/workbench/api/common/extHostApiCommands.ts b/src/vs/workbench/api/common/extHostApiCommands.ts
index 12d2a2b..05e3f11 100644
index 436e350..f426464 100644
--- a/src/vs/workbench/api/common/extHostApiCommands.ts
+++ b/src/vs/workbench/api/common/extHostApiCommands.ts
@@ -436,3 +436,3 @@ const newCommands: ApiCommand[] = [
@@ -443,3 +443,3 @@ const newCommands: ApiCommand[] = [
ApiCommandArgument.Uri.with('resource', 'Resource to open'),
- ApiCommandArgument.String.with('viewId', 'Custom editor view id. This should be the viewType string for custom editors or the notebookType string for notebooks. Use \'default\' to use VS Code\'s default text editor'),
+ ApiCommandArgument.String.with('viewId', 'Custom editor view id. This should be the viewType string for custom editors or the notebookType string for notebooks. Use \'default\' to use !!APP_NAME!!\'s default text editor'),
@@ -736,24 +736,24 @@ index 0ebe271..20974b2 100644
+ throw new Error('Unable to create the !!APP_NAME!! workbench more than once.');
} else {
diff --git a/src/vs/workbench/browser/workbench.contribution.ts b/src/vs/workbench/browser/workbench.contribution.ts
index 3a756fb..327ce60 100644
index e214bf7..efb48d6 100644
--- a/src/vs/workbench/browser/workbench.contribution.ts
+++ b/src/vs/workbench/browser/workbench.contribution.ts
@@ -697,3 +697,3 @@ const registry = Registry.as<IConfigurationRegistry>(ConfigurationExtensions.Con
@@ -704,3 +704,3 @@ const registry = Registry.as<IConfigurationRegistry>(ConfigurationExtensions.Con
localize('profileName', "`${profileName}`: name of the profile in which the workspace is opened (e.g. Data Science (Profile)). Ignored if default profile is used."),
- localize('appName', "`${appName}`: e.g. VS Code."),
+ localize('appName', "`${appName}`: e.g. !!APP_NAME!!."),
localize('remoteName', "`${remoteName}`: e.g. SSH"),
diff --git a/src/vs/workbench/contrib/chat/browser/chatSetup.ts b/src/vs/workbench/contrib/chat/browser/chatSetup.ts
index 517b7cb..70a9c6e 100644
index 5ebe9c1..ff02d8b 100644
--- a/src/vs/workbench/contrib/chat/browser/chatSetup.ts
+++ b/src/vs/workbench/contrib/chat/browser/chatSetup.ts
@@ -146,3 +146,3 @@ class SetupAgent extends Disposable implements IChatAgentImplementation {
@@ -140,3 +140,3 @@ class SetupAgent extends Disposable implements IChatAgentImplementation {
- const { agent, disposable } = SetupAgent.doRegisterAgent(instantiationService, chatAgentService, 'setup.vscode', 'vscode', false, localize2('vscodeAgentDescription', "Ask questions about VS Code").value, ChatAgentLocation.Panel, undefined, context, controller);
+ const { agent, disposable } = SetupAgent.doRegisterAgent(instantiationService, chatAgentService, 'setup.vscode', 'vscode', false, localize2('vscodeAgentDescription', "Ask questions about !!APP_NAME!!").value, ChatAgentLocation.Panel, undefined, context, controller);
disposables.add(disposable);
@@ -154,4 +154,4 @@ class SetupAgent extends Disposable implements IChatAgentImplementation {
@@ -148,4 +148,4 @@ class SetupAgent extends Disposable implements IChatAgentImplementation {
displayName: localize('setupToolDisplayName', "New Workspace"),
- modelDescription: localize('setupToolsDescription', "Scaffold a new workspace in VS Code"),
- userDescription: localize('setupToolsDescription', "Scaffold a new workspace in VS Code"),
@@ -770,30 +770,30 @@ index 0a13063..5a342c0 100644
+ description: nls.localize('debugServer', "For debug extension development only: if a port is specified !!APP_NAME!! tries to connect to a debug adapter running in server mode"),
default: 4711
diff --git a/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts b/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
index 816f372..2e74558 100644
index d2ae6b2..946e182 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensions.contribution.ts
@@ -337,3 +337,3 @@ CommandsRegistry.registerCommand({
@@ -338,3 +338,3 @@ CommandsRegistry.registerCommand({
description: '(optional) Options for installing the extension. Object with the following properties: ' +
- '`installOnlyNewlyAddedFromExtensionPackVSIX`: When enabled, VS Code installs only newly added extensions from the extension pack VSIX. This option is considered only when installing VSIX. ',
+ '`installOnlyNewlyAddedFromExtensionPackVSIX`: When enabled, !!APP_NAME!! installs only newly added extensions from the extension pack VSIX. This option is considered only when installing VSIX. ',
isOptional: true,
@@ -344,3 +344,3 @@ CommandsRegistry.registerCommand({
@@ -345,3 +345,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.installOnlyNewlyAddedFromExtensionPackVSIX', "When enabled, VS Code installs only newly added extensions from the extension pack VSIX. This option is considered only while installing a VSIX."),
+ 'description': localize('workbench.extensions.installExtension.option.installOnlyNewlyAddedFromExtensionPackVSIX', "When enabled, !!APP_NAME!! installs only newly added extensions from the extension pack VSIX. This option is considered only while installing a VSIX."),
default: false
@@ -349,3 +349,3 @@ CommandsRegistry.registerCommand({
@@ -350,3 +350,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.installPreReleaseVersion', "When enabled, VS Code installs the pre-release version of the extension if available."),
+ 'description': localize('workbench.extensions.installExtension.option.installPreReleaseVersion', "When enabled, !!APP_NAME!! installs the pre-release version of the extension if available."),
default: false
@@ -354,3 +354,3 @@ CommandsRegistry.registerCommand({
@@ -355,3 +355,3 @@ CommandsRegistry.registerCommand({
'type': 'boolean',
- 'description': localize('workbench.extensions.installExtension.option.donotSync', "When enabled, VS Code do not sync this extension when Settings Sync is on."),
+ 'description': localize('workbench.extensions.installExtension.option.donotSync', "When enabled, !!APP_NAME!! do not sync this extension when Settings Sync is on."),
default: false
@@ -878,4 +878,4 @@ class ExtensionsContributions extends Disposable implements IWorkbenchContributi
@@ -880,4 +880,4 @@ class ExtensionsContributions extends Disposable implements IWorkbenchContributi
Severity.Info,
- vsixs.length > 1 ? localize('InstallVSIXs.successReload', "Completed installing extensions. Please reload Visual Studio Code to enable them.")
- : localize('InstallVSIXAction.successReload', "Completed installing extension. Please reload Visual Studio Code to enable it."),
@@ -825,15 +825,15 @@ index 1fc3f63..c1f8609 100644
+ this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to !!APP_NAME!!. Configure these {0} to use this functionality.", link)) }, true);
} else {
diff --git a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
index 3a66a88..63d32c3 100644
index 1cc4741..5512fb5 100644
--- a/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
+++ b/src/vs/workbench/contrib/tasks/browser/abstractTaskService.ts
@@ -3321,3 +3321,3 @@ export abstract class AbstractTaskService extends Disposable implements ITaskSer
@@ -3327,3 +3327,3 @@ export abstract class AbstractTaskService extends Disposable implements ITaskSer
if (response.code && response.code === TerminateResponseCode.ProcessNotFound) {
- this._notificationService.error(nls.localize('TerminateAction.noProcess', 'The launched process doesn\'t exist anymore. If the task spawned background tasks exiting VS Code might result in orphaned processes.'));
+ this._notificationService.error(nls.localize('TerminateAction.noProcess', 'The launched process doesn\'t exist anymore. If the task spawned background tasks exiting !!APP_NAME!! might result in orphaned processes.'));
@@ -1037,7 +1037,7 @@ index ab7fcb4..12c26ee 100644
+ localize({ comment: ['This is the description for a setting. Values surrounded by single quotes are not to be translated.'], key: 'workbench.startupEditor.welcomePage' }, "Open the Welcome page, with content to aid in getting started with !!APP_NAME!! and extensions."),
localize({ comment: ['This is the description for a setting. Values surrounded by single quotes are not to be translated.'], key: 'workbench.startupEditor.readme' }, "Open the README when opening a folder that contains one, fallback to 'welcomePage' otherwise. Note: This is only observed as a global configuration, it will be ignored if set in a workspace or folder configuration."),
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
index 77a3a36..1d25064 100644
index 61c0a56..67ff15e 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/browser/gettingStarted.ts
@@ -20,3 +20,3 @@ import { splitRecentLabel } from '../../../../base/common/labels.js';
@@ -1067,25 +1067,16 @@ index 3f1c098..26bf670 100644
+ description: localize('walkthroughs.steps.completionEvents.onCommand', 'Check off step when a given command is executed anywhere in !!APP_NAME!!.'),
body: 'onCommand:${1:commandId}'
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts b/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
index fad3c94..ccd635d 100644
index ac2672d..0da92bf 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
@@ -15,3 +15,2 @@ import { CONTEXT_ACCESSIBILITY_MODE_ENABLED } from '../../../../platform/accessi
import { URI } from '../../../../base/common/uri.js';
-import product from '../../../../platform/product/common/product.js';
@@ -21,4 +20,2 @@ interface IGettingStartedContentProvider {
-export const copilotSettingsMessage = localize({ key: 'settings', comment: ['{Locked="["}', '{Locked="]({0})"}', '{Locked="]({1})"}'] }, "{0} Copilot Free, Pro and Pro+ may show [public code]({1}) suggestions and we may use your data for product improvement. You can change these [settings]({2}) at any time.", product.defaultChatAgent?.providerName, product.defaultChatAgent?.publicCodeMatchesUrl, product.defaultChatAgent?.manageSettingsUrl);
-
class GettingStartedContentProviderRegistry {
@@ -203,13 +200,2 @@ export const startEntries: GettingStartedStartEntryContent = [
@@ -210,13 +210,2 @@ export const startEntries: GettingStartedStartEntryContent = [
},
- {
- id: 'topLevelNewWorkspaceChat',
- title: localize('gettingStarted.newWorkspaceChat.title', "New Workspace with Copilot..."),
- description: localize('gettingStarted.newWorkspaceChat.description', "Create a new workspace with Copilot"),
- icon: Codicon.copilot,
- title: localize('gettingStarted.newWorkspaceChat.title', "Generate New Workspace..."),
- description: localize('gettingStarted.newWorkspaceChat.description', "Chat to create a new workspace"),
- icon: Codicon.chatSparkle,
- when: '!isWeb && !chatSetupHidden',
- content: {
- type: 'startEntry',
@@ -1093,10 +1084,10 @@ index fad3c94..ccd635d 100644
- }
- },
];
@@ -218,24 +204,2 @@ const Button = (title: string, href: string) => `[${title}](${href})`;
@@ -225,24 +214,2 @@ const Button = (title: string, href: string) => `[${title}](${href})`;
-const CopilotStepTitle = localize('gettingStarted.copilotSetup.title', "Use AI features with Copilot for free");
-const CopilotDescription = localize({ key: 'gettingStarted.copilotSetup.description', comment: ['{Locked="["}', '{Locked="]({0})"}'] }, "You can use [Copilot]({0}) to generate code across multiple files, fix errors, ask questions about your code and much more using natural language.", product.defaultChatAgent?.documentationUrl ?? '');
-const CopilotDescription = localize({ key: 'gettingStarted.copilotSetup.description', comment: ['{Locked="["}', '{Locked="]({0})"}'] }, "You can use [Copilot]({0}) to generate code across multiple files, fix errors, ask questions about your code and much more using natural language.", defaultChat.documentationUrl ?? '');
-const CopilotSignedOutButton = Button(localize('setupCopilotButton.signIn', "Set up Copilot"), `command:workbench.action.chat.triggerSetup`);
-const CopilotSignedInButton = Button(localize('setupCopilotButton.setup', "Set up Copilot"), `command:workbench.action.chat.triggerSetup`);
-const CopilotCompleteButton = Button(localize('setupCopilotButton.chatWithCopilot', "Chat with Copilot"), 'command:workbench.action.chat.open');
@@ -1118,23 +1109,23 @@ index fad3c94..ccd635d 100644
-}
-
export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -243,3 +207,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -250,3 +217,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
id: 'Setup',
- title: localize('gettingStarted.setup.title', "Get started with VS Code"),
+ title: localize('gettingStarted.setup.title', "Get started with !!APP_NAME!!"),
description: localize('gettingStarted.setup.description', "Customize your editor, learn the basics, and start coding"),
@@ -248,3 +212,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -255,3 +222,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
when: '!isWeb',
- walkthroughPageTitle: localize('gettingStarted.setup.walkthroughPageTitle', 'Setup VS Code'),
+ walkthroughPageTitle: localize('gettingStarted.setup.walkthroughPageTitle', 'Setup !!APP_NAME!!'),
next: 'Beginner',
@@ -253,5 +217,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -260,5 +227,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
steps: [
- createCopilotSetupStep('CopilotSetupSignedOut', CopilotSignedOutButton, 'chatEntitlementSignedOut', true),
- createCopilotSetupStep('CopilotSetupComplete', CopilotCompleteButton, 'chatSetupInstalled && !chatSetupDisabled && (chatPlanPro || chatPlanProPlus || chatPlanBusiness || chatPlanEnterprise || chatPlanFree)', false),
- createCopilotSetupStep('CopilotSetupSignedIn', CopilotSignedInButton, '!chatEntitlementSignedOut && (!chatSetupInstalled || chatSetupDisabled || chatPlanCanSignUp)', true),
{
@@ -269,6 +230,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -276,6 +240,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.extensions.title', "Code with extensions"),
- description: localize('gettingStarted.extensionsWeb.description.interpolated', "Extensions are VS Code's power-ups. A growing number are becoming available in the web.\n{0}", Button(localize('browsePopularWeb', "Browse Popular Web Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
+ description: localize('gettingStarted.extensionsWeb.description.interpolated', "Extensions are !!APP_NAME!!'s power-ups. A growing number are becoming available in the web.\n{0}", Button(localize('browsePopularWeb', "Browse Popular Web Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
@@ -1143,7 +1134,7 @@ index fad3c94..ccd635d 100644
- type: 'svg', altText: 'VS Code extension marketplace with featured language extensions', path: 'extensions-web.svg'
+ type: 'svg', altText: '!!APP_NAME!! extension marketplace with featured language extensions', path: 'extensions-web.svg'
},
@@ -284,21 +245,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -291,21 +255,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
},
- // Hidden in favor of copilot entry (to be revisited when copilot entry moves, if at all)
- // {
@@ -1165,17 +1156,17 @@ index fad3c94..ccd635d 100644
- // },
- // },
{
@@ -306,3 +248,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -313,3 +258,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.settings.title', "Tune your settings"),
- description: localize('gettingStarted.settingsAndSync.description.interpolated', "Customize every aspect of VS Code and your extensions to your liking. [Back up and sync](command:workbench.userDataSync.actions.turnOn) your essential customizations across all your devices.\n{0}", Button(localize('tweakSettings', "Open Settings"), 'command:toSide:workbench.action.openSettings')),
+ description: localize('gettingStarted.settingsAndSync.description.interpolated', "Customize every aspect of !!APP_NAME!! and your extensions to your liking. [Back up and sync](command:workbench.userDataSync.actions.turnOn) your essential customizations across all your devices.\n{0}", Button(localize('tweakSettings', "Open Settings"), 'command:toSide:workbench.action.openSettings')),
when: 'syncStatus != uninitialized',
@@ -310,3 +252,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -317,3 +262,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
media: {
- type: 'svg', altText: 'VS Code Settings', path: 'settings.svg'
+ type: 'svg', altText: '!!APP_NAME!! Settings', path: 'settings.svg'
},
@@ -316,24 +258,5 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -323,24 +268,5 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.commandPalette.title', "Unlock productivity with the Command Palette "),
- description: localize('gettingStarted.commandPalette.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in VS Code.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
+ description: localize('gettingStarted.commandPalette.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in !!APP_NAME!!.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
@@ -1201,24 +1192,24 @@ index fad3c94..ccd635d 100644
- // }
- // },
{
@@ -350,4 +273,4 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -357,4 +283,4 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.videoTutorial.title', "Watch video tutorials"),
- description: localize('gettingStarted.videoTutorial.description.interpolated', "Watch the first in a series of short & practical video tutorials for VS Code's key features.\n{0}", Button(localize('watch', "Watch Tutorial"), 'https://aka.ms/vscode-getting-started-video')),
- media: { type: 'svg', altText: 'VS Code Settings', path: 'learn.svg' },
+ description: localize('gettingStarted.videoTutorial.description.interpolated', "Watch the first in a series of short & practical video tutorials for !!APP_NAME!!'s key features.\n{0}", Button(localize('watch', "Watch Tutorial"), 'https://aka.ms/vscode-getting-started-video')),
+ media: { type: 'svg', altText: '!!APP_NAME!! Settings', path: 'learn.svg' },
}
@@ -359,3 +282,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -366,3 +292,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
id: 'SetupWeb',
- title: localize('gettingStarted.setupWeb.title', "Get Started with VS Code for the Web"),
+ title: localize('gettingStarted.setupWeb.title', "Get Started with !!APP_NAME!! for the Web"),
description: localize('gettingStarted.setupWeb.description', "Customize your editor, learn the basics, and start coding"),
@@ -365,3 +288,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -372,3 +298,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
next: 'Beginner',
- walkthroughPageTitle: localize('gettingStarted.setupWeb.walkthroughPageTitle', 'Setup VS Code Web'),
+ walkthroughPageTitle: localize('gettingStarted.setupWeb.walkthroughPageTitle', 'Setup !!APP_NAME!! Web'),
content: {
@@ -391,6 +314,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -398,6 +324,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.extensions.title', "Code with extensions"),
- description: localize('gettingStarted.extensionsWeb.description.interpolated', "Extensions are VS Code's power-ups. A growing number are becoming available in the web.\n{0}", Button(localize('browsePopularWeb', "Browse Popular Web Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
+ description: localize('gettingStarted.extensionsWeb.description.interpolated', "Extensions are !!APP_NAME!!'s power-ups. A growing number are becoming available in the web.\n{0}", Button(localize('browsePopularWeb', "Browse Popular Web Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
@@ -1227,7 +1218,7 @@ index fad3c94..ccd635d 100644
- type: 'svg', altText: 'VS Code extension marketplace with featured language extensions', path: 'extensions-web.svg'
+ type: 'svg', altText: '!!APP_NAME!! extension marketplace with featured language extensions', path: 'extensions-web.svg'
},
@@ -406,12 +329,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -413,12 +339,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
},
- {
- id: 'settingsSyncWeb',
@@ -1240,32 +1231,32 @@ index fad3c94..ccd635d 100644
- },
- },
{
@@ -419,3 +332,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -426,3 +342,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.commandPalette.title', "Unlock productivity with the Command Palette "),
- description: localize('gettingStarted.commandPalette.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in VS Code.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
+ description: localize('gettingStarted.commandPalette.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in !!APP_NAME!!.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
media: { type: 'svg', altText: 'Command Palette overlay for searching and executing commands.', path: 'commandPalette.svg' },
@@ -425,3 +338,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -432,3 +348,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.setup.OpenFolder.title', "Open up your code"),
- description: localize('gettingStarted.setup.OpenFolderWeb.description.interpolated', "You're all set to start coding. You can open a local project or a remote repository to get your files into VS Code.\n{0}\n{1}", Button(localize('openFolder', "Open Folder"), 'command:workbench.action.addRootFolder'), Button(localize('openRepository', "Open Repository"), 'command:remoteHub.openRepository')),
+ description: localize('gettingStarted.setup.OpenFolderWeb.description.interpolated', "You're all set to start coding. You can open a local project or a remote repository to get your files into !!APP_NAME!!.\n{0}\n{1}", Button(localize('openFolder', "Open Folder"), 'command:workbench.action.addRootFolder'), Button(localize('openRepository', "Open Repository"), 'command:remoteHub.openRepository')),
when: 'workspaceFolderCount == 0',
@@ -446,3 +359,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -453,3 +369,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.setupAccessibility.title', "Get Started with Accessibility Features"),
- description: localize('gettingStarted.setupAccessibility.description', "Learn the tools and shortcuts that make VS Code accessible. Note that some actions are not actionable from within the context of the walkthrough."),
+ description: localize('gettingStarted.setupAccessibility.description', "Learn the tools and shortcuts that make !!APP_NAME!! accessible. Note that some actions are not actionable from within the context of the walkthrough."),
isFeatured: true,
@@ -451,3 +364,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -458,3 +374,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
next: 'Setup',
- walkthroughPageTitle: localize('gettingStarted.setupAccessibility.walkthroughPageTitle', 'Setup VS Code Accessibility'),
+ walkthroughPageTitle: localize('gettingStarted.setupAccessibility.walkthroughPageTitle', 'Setup !!APP_NAME!! Accessibility'),
content: {
@@ -482,3 +395,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -489,3 +405,3 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.commandPaletteAccessibility.title', "Unlock productivity with the Command Palette "),
- description: localize('gettingStarted.commandPaletteAccessibility.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in VS Code.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
+ description: localize('gettingStarted.commandPaletteAccessibility.description.interpolated', "Run commands without reaching for your mouse to accomplish any task in !!APP_NAME!!.\n{0}", Button(localize('commandPalette', "Open Command Palette"), 'command:workbench.action.showCommands')),
media: { type: 'markdown', path: 'empty' },
@@ -555,6 +468,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -562,6 +478,6 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
title: localize('gettingStarted.extensions.title', "Code with extensions"),
- description: localize('gettingStarted.extensions.description.interpolated', "Extensions are VS Code's power-ups. They range from handy productivity hacks, expanding out-of-the-box features, to adding completely new capabilities.\n{0}", Button(localize('browsePopular', "Browse Popular Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
+ description: localize('gettingStarted.extensions.description.interpolated', "Extensions are !!APP_NAME!!'s power-ups. They range from handy productivity hacks, expanding out-of-the-box features, to adding completely new capabilities.\n{0}", Button(localize('browsePopular', "Browse Popular Extensions"), 'command:workbench.extensions.action.showPopularExtensions')),
@@ -1274,7 +1265,7 @@ index fad3c94..ccd635d 100644
- type: 'svg', altText: 'VS Code extension marketplace with featured language extensions', path: 'extensions.svg'
+ type: 'svg', altText: '!!APP_NAME!! extension marketplace with featured language extensions', path: 'extensions.svg'
},
@@ -672,66 +585,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
@@ -679,66 +595,2 @@ export const walkthroughs: GettingStartedWalkthroughContent = [
},
- {
- id: `${NEW_WELCOME_EXPERIENCE}`,
@@ -1306,7 +1297,7 @@ index fad3c94..ccd635d 100644
- {
- id: 'copilotSetup.customize',
- title: localize('gettingStarted.customize.title', "Personalized to how you work"),
- description: localize('gettingStarted.customize.description', "Swap models, add agent mode tools, and create personalized instructions.\n{0}", Button(localize('signUp', "Set up AI"), 'command:workbench.action.chat.triggerSetupWithoutDialog')),
- description: localize('gettingStarted.customize.description', "Swap models, add agent mode tools, and create personalized instructions.\n{0}", Button(localize('signUp', "Enable AI features"), 'command:workbench.action.chat.triggerSetupWithoutDialog')),
- media: {
- type: 'svg', altText: 'Personalize', path: 'customize-ai.svg'
- },
@@ -1389,7 +1380,7 @@ index e6805ca..f61cecc 100644
+ const productName = localize('!!APP_NAME!! for Web', "{0} for the Web", this.productService.nameLong);
const virtualWorkspaceSupport = this.extensionManifestPropertiesService.getExtensionVirtualWorkspaceSupportType(manifest);
diff --git a/src/vs/workbench/services/extensions/common/extensionsRegistry.ts b/src/vs/workbench/services/extensions/common/extensionsRegistry.ts
index 859b976..06386e0 100644
index 451dbcd..2782013 100644
--- a/src/vs/workbench/services/extensions/common/extensionsRegistry.ts
+++ b/src/vs/workbench/services/extensions/common/extensionsRegistry.ts
@@ -181,3 +181,3 @@ export const schema: IJSONSchema = {
@@ -1431,17 +1422,17 @@ index 859b976..06386e0 100644
- description: nls.localize('vscode.extension.activationEvents', 'Activation events for the VS Code extension.'),
+ description: nls.localize('vscode.extension.activationEvents', 'Activation events for the !!APP_NAME!! extension.'),
type: 'array',
@@ -412,3 +412,3 @@ export const schema: IJSONSchema = {
@@ -422,3 +422,3 @@ export const schema: IJSONSchema = {
label: '*',
- description: nls.localize('vscode.extension.activationEvents.star', 'An activation event emitted on VS Code startup. To ensure a great end user experience, please use this activation event in your extension only when no other activation events combination works in your use-case.'),
+ description: nls.localize('vscode.extension.activationEvents.star', 'An activation event emitted on !!APP_NAME!! startup. To ensure a great end user experience, please use this activation event in your extension only when no other activation events combination works in your use-case.'),
body: '*'
@@ -584,3 +584,3 @@ export const schema: IJSONSchema = {
@@ -594,3 +594,3 @@ export const schema: IJSONSchema = {
'vscode:prepublish': {
- description: nls.localize('vscode.extension.scripts.prepublish', 'Script executed before the package is published as a VS Code extension.'),
+ description: nls.localize('vscode.extension.scripts.prepublish', 'Script executed before the package is published as a !!APP_NAME!! extension.'),
type: 'string'
@@ -588,3 +588,3 @@ export const schema: IJSONSchema = {
@@ -598,3 +598,3 @@ export const schema: IJSONSchema = {
'vscode:uninstall': {
- description: nls.localize('vscode.extension.scripts.uninstall', 'Uninstall hook for VS Code extension. Script that gets executed when the extension is completely uninstalled from VS Code which is when VS Code is restarted (shutdown and start) after the extension is uninstalled. Only Node scripts are supported.'),
+ description: nls.localize('vscode.extension.scripts.uninstall', 'Uninstall hook for !!APP_NAME!! extension. Script that gets executed when the extension is completely uninstalled from !!APP_NAME!! which is when !!APP_NAME!! is restarted (shutdown and start) after the extension is uninstalled. Only Node scripts are supported.'),

View File

@@ -1,8 +1,39 @@
diff --git a/.vscode/settings.json b/.vscode/settings.json
index 99e495a..996044a 100644
index 31b1c4a..f808aa6 100644
--- a/.vscode/settings.json
+++ b/.vscode/settings.json
@@ -10,5 +10,5 @@
@@ -17,23 +17,23 @@
},
"[typescript]": {
"editor.defaultFormatter": "vscode.typescript-language-features",
- "editor.formatOnSave": true
+ // "editor.formatOnSave": true
},
"[javascript]": {
"editor.defaultFormatter": "vscode.typescript-language-features",
- "editor.formatOnSave": true
+ // "editor.formatOnSave": true
},
"[rust]": {
"editor.defaultFormatter": "rust-lang.rust-analyzer",
- "editor.formatOnSave": true,
+ // "editor.formatOnSave": true,
},
"[github-issues]": {
"editor.wordWrap": "on"
},
// --- Files ---
- "files.trimTrailingWhitespace": true,
- "files.insertFinalNewline": true,
+ // "files.trimTrailingWhitespace": true,
+ // "files.insertFinalNewline": true,
"files.exclude": {
".git": true,
".build": true,
@@ -42,9 +42,9 @@
".vscode-test": true,
"cli/target": true,
"build/**/*.js.map": true,
- "build/**/*.js": {
- "when": "$(basename).ts"
@@ -11,27 +42,22 @@ index 99e495a..996044a 100644
+ // "when": "$(basename).ts"
+ // }
},
@@ -59,2 +59,3 @@
"files.associations": {
"cglicenses.json": "jsonc",
@@ -55,7 +55,7 @@
"**/yarn.lock": true,
"**/package-lock.json": true,
"**/Cargo.lock": true,
- "build/**/*.js": true,
+ // "build/**/*.js": true,
"out/**": true,
"out-build/**": true,
"out-vscode/**": true,
@@ -71,6 +71,7 @@
"build/builtin/*.js": true,
"build/monaco/*.js": true,
"build/npm/*.js": true,
+ "build/**/*.js": true,
"build/*.js": true
@@ -108,3 +109,3 @@
"gulp.autoDetect": "off",
- "files.insertFinalNewline": true,
+ // "files.insertFinalNewline": true,
"[plaintext]": {
@@ -114,3 +115,3 @@
"editor.defaultFormatter": "vscode.typescript-language-features",
- "editor.formatOnSave": true
+ // "editor.formatOnSave": true
},
@@ -118,3 +119,3 @@
"editor.defaultFormatter": "vscode.typescript-language-features",
- "editor.formatOnSave": true
+ // "editor.formatOnSave": true
},
@@ -122,3 +123,3 @@
"editor.defaultFormatter": "rust-lang.rust-analyzer",
- "editor.formatOnSave": true,
+ // "editor.formatOnSave": true,
},

View File

@@ -1,15 +0,0 @@
diff --git a/build/gulpfile.vscode.win32.js b/build/gulpfile.vscode.win32.js
index 5adfdfb..dfdb2af 100644
--- a/build/gulpfile.vscode.win32.js
+++ b/build/gulpfile.vscode.win32.js
@@ -115,6 +115,6 @@ function buildWin32Setup(arch, target) {
- if (quality === 'insider') {
- definitions['AppxPackage'] = `code_insiders_explorer_${arch}.appx`;
- definitions['AppxPackageFullname'] = `Microsoft.${product.win32RegValueName}_1.0.0.0_neutral__8wekyb3d8bbwe`;
- }
+ // if (quality === 'insider') {
+ // definitions['AppxPackage'] = `code_insiders_explorer_${arch}.appx`;
+ // definitions['AppxPackageFullname'] = `Microsoft.${product.win32RegValueName}_1.0.0.0_neutral__8wekyb3d8bbwe`;
+ // }

View File

@@ -1,19 +1,19 @@
diff --git a/build/linux/dependencies-generator.js b/build/linux/dependencies-generator.js
index 7521729..92c0d8e 100644
index 1dfaeb3..c5ff6d3 100644
--- a/build/linux/dependencies-generator.js
+++ b/build/linux/dependencies-generator.js
@@ -27,3 +27,3 @@ const product = require("../../product.json");
// are valid, are in dep-lists.ts
-const FAIL_BUILD_FOR_NEW_DEPENDENCIES = true;
+const FAIL_BUILD_FOR_NEW_DEPENDENCIES = false;
// Based on https://source.chromium.org/chromium/chromium/src/+/refs/tags/134.0.6998.205:chrome/installer/linux/BUILD.gn;l=64-80
// Based on https://source.chromium.org/chromium/chromium/src/+/refs/tags/138.0.7204.100:chrome/installer/linux/BUILD.gn;l=64-80
@@ -60,3 +60,3 @@ async function getDependencies(packageType, buildDir, applicationName, arch) {
// Add the tunnel binary.
- files.push(path_1.default.join(buildDir, 'bin', product.tunnelApplicationName));
+ // files.push(path_1.default.join(buildDir, 'bin', product.tunnelApplicationName));
// Add the main executable.
diff --git a/build/linux/dependencies-generator.ts b/build/linux/dependencies-generator.ts
index 9383703..5e6bcf2 100644
index 1aab03f..ec859f1 100644
--- a/build/linux/dependencies-generator.ts
+++ b/build/linux/dependencies-generator.ts
@@ -25,3 +25,3 @@ import product = require('../../product.json');

View File

@@ -0,0 +1,56 @@
diff --git a/build/gulpfile.vscode.js b/build/gulpfile.vscode.js
index 25d8916..95863d2 100644
--- a/build/gulpfile.vscode.js
+++ b/build/gulpfile.vscode.js
@@ -406,18 +406,18 @@ function packageTask(platform, arch, sourceFolderName, destinationFolderName, op
- if (quality !== 'exploration') {
- result = es.merge(result, gulp.src('.build/win32/appx/**', { base: '.build/win32' }));
- const rawVersion = version.replace(/-\w+$/, '').split('.');
- const appxVersion = `${rawVersion[0]}.0.${rawVersion[1]}.${rawVersion[2]}`;
- result = es.merge(result, gulp.src('resources/win32/appx/AppxManifest.xml', { base: '.' })
- .pipe(replace('@@AppxPackageName@@', product.win32AppUserModelId))
- .pipe(replace('@@AppxPackageVersion@@', appxVersion))
- .pipe(replace('@@AppxPackageDisplayName@@', product.nameLong))
- .pipe(replace('@@AppxPackageDescription@@', product.win32NameVersion))
- .pipe(replace('@@ApplicationIdShort@@', product.win32RegValueName))
- .pipe(replace('@@ApplicationExe@@', product.nameShort + '.exe'))
- .pipe(replace('@@FileExplorerContextMenuID@@', quality === 'stable' ? 'OpenWithCode' : 'OpenWithCodeInsiders'))
- .pipe(replace('@@FileExplorerContextMenuCLSID@@', product.win32ContextMenu[arch].clsid))
- .pipe(replace('@@FileExplorerContextMenuDLL@@', `${quality === 'stable' ? 'code' : 'code_insider'}_explorer_command_${arch}.dll`))
- .pipe(rename(f => f.dirname = `appx/manifest`)));
- }
+ // if (quality !== 'exploration') {
+ // result = es.merge(result, gulp.src('.build/win32/appx/**', { base: '.build/win32' }));
+ // const rawVersion = version.replace(/-\w+$/, '').split('.');
+ // const appxVersion = `${rawVersion[0]}.0.${rawVersion[1]}.${rawVersion[2]}`;
+ // result = es.merge(result, gulp.src('resources/win32/appx/AppxManifest.xml', { base: '.' })
+ // .pipe(replace('@@AppxPackageName@@', product.win32AppUserModelId))
+ // .pipe(replace('@@AppxPackageVersion@@', appxVersion))
+ // .pipe(replace('@@AppxPackageDisplayName@@', product.nameLong))
+ // .pipe(replace('@@AppxPackageDescription@@', product.win32NameVersion))
+ // .pipe(replace('@@ApplicationIdShort@@', product.win32RegValueName))
+ // .pipe(replace('@@ApplicationExe@@', product.nameShort + '.exe'))
+ // .pipe(replace('@@FileExplorerContextMenuID@@', `OpenWith${product.win32RegValueName}`))
+ // .pipe(replace('@@FileExplorerContextMenuCLSID@@', product.win32ContextMenu[arch].clsid))
+ // .pipe(replace('@@FileExplorerContextMenuDLL@@', `${product.applicationName.replace(/-/g, '_')}_explorer_command_${arch}.dll`))
+ // .pipe(rename(f => f.dirname = `appx/manifest`)));
+ // }
} else if (platform === 'linux') {
diff --git a/build/gulpfile.vscode.win32.js b/build/gulpfile.vscode.win32.js
index 0c4dc52..156322b 100644
--- a/build/gulpfile.vscode.win32.js
+++ b/build/gulpfile.vscode.win32.js
@@ -114,7 +114,7 @@ function buildWin32Setup(arch, target) {
- if (quality !== 'exploration') {
- definitions['AppxPackage'] = `${quality === 'stable' ? 'code' : 'code_insider'}_${arch}.appx`;
- definitions['AppxPackageDll'] = `${quality === 'stable' ? 'code' : 'code_insider'}_explorer_command_${arch}.dll`;
- definitions['AppxPackageName'] = `${product.win32AppUserModelId}`;
- }
+ // if (quality !== 'exploration') {
+ // definitions['AppxPackage'] = `${product.applicationName.replace(/-/g, '_')}_${arch}.appx`;
+ // definitions['AppxPackageDll'] = `${product.applicationName.replace(/-/g, '_')}_explorer_command_${arch}.dll`;
+ // definitions['AppxPackageName'] = `${product.win32AppUserModelId}`;
+ // }

View File

@@ -101,6 +101,8 @@ elif [[ "${OS_NAME}" == "windows" ]]; then
7z.exe a -tzip "../assets/${APP_NAME}-win32-${VSCODE_ARCH}-${RELEASE_VERSION}.zip" -x!CodeSignSummary*.md -x!tools "../VSCode-win32-${VSCODE_ARCH}/*" -r
fi
# . ../build/windows/appx/build.sh
if [[ "${SHOULD_BUILD_EXE_SYS}" != "no" ]]; then
npm run gulp "vscode-win32-${VSCODE_ARCH}-system-setup"
fi

View File

@@ -100,7 +100,7 @@ mv .npmrc.bak .npmrc
setpath() {
local jsonTmp
{ set +x; } 2>/dev/null
jsonTmp=$( jq --arg 'path' "${2}" --arg 'value' "${3}" 'setpath([$path]; $value)' "${1}.json" )
jsonTmp=$( jq --arg 'value' "${3}" "setpath(path(.${2}); \$value)" "${1}.json" )
echo "${jsonTmp}" > "${1}.json"
set -x
}
@@ -108,7 +108,7 @@ setpath() {
setpath_json() {
local jsonTmp
{ set +x; } 2>/dev/null
jsonTmp=$( jq --arg 'path' "${2}" --argjson 'value' "${3}" 'setpath([$path]; $value)' "${1}.json" )
jsonTmp=$( jq --argjson 'value' "${3}" "setpath(path(.${2}); \$value)" "${1}.json" )
echo "${jsonTmp}" > "${1}.json"
set -x
}
@@ -167,6 +167,8 @@ if [[ "${VSCODE_QUALITY}" == "insider" ]]; then
setpath "product" "tunnelApplicationName" "codium-tunnel-insiders"
setpath "product" "win32TunnelServiceMutex" "vscodiuminsiders-tunnelservice"
setpath "product" "win32TunnelMutex" "vscodiuminsiders-tunnel"
setpath "product" "win32ContextMenu.x64.clsid" "90AAD229-85FD-43A3-B82D-8598A88829CF"
setpath "product" "win32ContextMenu.arm64.clsid" "7544C31C-BDBF-4DDF-B15E-F73A46D6723D"
else
setpath "product" "nameShort" "VSCodium"
setpath "product" "nameLong" "VSCodium"
@@ -192,6 +194,8 @@ else
setpath "product" "tunnelApplicationName" "codium-tunnel"
setpath "product" "win32TunnelServiceMutex" "vscodium-tunnelservice"
setpath "product" "win32TunnelMutex" "vscodium-tunnel"
setpath "product" "win32ContextMenu.x64.clsid" "D910D5E6-B277-4F4A-BDC5-759A34EEE25D"
setpath "product" "win32ContextMenu.arm64.clsid" "4852FC55-4A84-4EA1-9C86-D53BE3DF83C0"
fi
jsonTmp=$( jq -s '.[0] * .[1]' product.json ../product.json )

View File

@@ -186,6 +186,7 @@
"activeComment",
"chatParticipantAdditions",
"chatParticipantPrivate",
"chatSessionsProvider",
"codiconDecoration",
"codeActionRanges",
"commentingRangeHint",
@@ -201,6 +202,8 @@
"contribMultiDiffEditorMenus",
"contribShareMenu",
"diffCommand",
"languageModelDataPart",
"languageModelToolResultAudience",
"quickDiffProvider",
"remoteCodingAgents",
"shareProvider",
@@ -258,7 +261,9 @@
"taskProblemMatcherStatus",
"contribLanguageModelToolSets",
"textDocumentChangeReason",
"resolvers"
"resolvers",
"taskExecutionTerminal",
"dataChannels"
],
"GitHub.remotehub": [
"contribRemoteHelp",

View File

@@ -1,4 +1,4 @@
{
"tag": "1.102.0",
"commit": "96f1890d08080f46f3b0a9424553422f04133090"
"tag": "1.103.0",
"commit": "e3550cfac4b63ca4eafca7b601f0d2885817fd1f"
}

View File

@@ -1,4 +1,4 @@
{
"tag": "1.102.3",
"commit": "488a1f239235055e34e673291fb8d8c810886f81"
"tag": "1.103.0",
"commit": "e3550cfac4b63ca4eafca7b601f0d2885817fd1f"
}
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
index 752dcc3..2e99608 100644
index 9927c14..c117131 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
@@ -476,3 +476,3 @@ export class Extension implements IExtension {
@@ -477,3 +477,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
## Features
@@ -514,3 +514,3 @@ ${this.description}
@@ -515,3 +515,3 @@ ${this.description}
if (this.type === ExtensionType.System) {
- return Promise.resolve(`Please check the [VS Code Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
+ return Promise.resolve(`Please check the [!!APP_NAME!! Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
@@ -894,10 +894,10 @@ index b533feb..112d695 100644
+ `// ${nls.localize('doc', 'Open !!APP_NAME!! and run "Developer: Inspect Key Mappings (JSON)" from Command Palette.')}`,
``,
@@ -477,3 +477,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
-**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
+**Notice:** This extension is bundled with !!APP_NAME!!. It can be disabled but not uninstalled.
## Features